@@ -1484,6 +1484,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         role = await self.auth.reqRole(iden)
         await role.setRules(rules, gateiden=gateiden)
 
+    async def setRoleName(self, iden, name):
+        role = await self.auth.reqRole(iden)
+        await role.setName(name)
+
     async def setUserAdmin(self, iden, admin, gateiden=None):
         user = await self.auth.reqUser(iden)
         await user.setAdmin(admin, gateiden=gateiden)
@@ -1523,6 +1527,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
     async def setUserEmail(self, useriden, email):
         await self.auth.setUserInfo(useriden, 'email', email)
 
+    async def setUserName(self, useriden, name):
+        user = await self.auth.reqUser(useriden)
+        await user.setName(name)
+
     async def setUserPasswd(self, iden, passwd):
         user = await self.auth.reqUser(iden)
         await user.setPasswd(passwd)
@@ -1855,7 +1863,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         '''
         extra = {**kwargs}
         sess = s_scope.get('sess')
-        if sess:
+        if sess and sess.user:
             extra['user'] = sess.user.iden
             extra['username'] = sess.user.name
         return {'synapse': extra}
