@@ -12,7 +12,6 @@ from prompt_toolkit import PromptSession, print_formatted_text
 from prompt_toolkit.formatted_text import FormattedText
 from prompt_toolkit.history import FileHistory
 from prompt_toolkit.patch_stdout import patch_stdout
-from prompt_toolkit.eventloop.defaults import use_asyncio_event_loop
 
 import synapse.exc as s_exc
 import synapse.common as s_common
@@ -20,6 +19,7 @@ import synapse.telepath as s_telepath
 
 import synapse.lib.base as s_base
 import synapse.lib.output as s_output
+import synapse.lib.parser as s_parser
 import synapse.lib.grammar as s_grammar
 import synapse.lib.version as s_version
 
@@ -29,10 +29,8 @@ logger = logging.getLogger(__name__)
 class Cmd:
     '''
     Base class for modular commands in the synapse CLI.
-
-    FIXME: document the _cmd_syntax definitions.
     '''
-    _cmd_name = 'FIXME'
+    _cmd_name = 'fixme'
     _cmd_syntax = ()
 
     def __init__(self, cli, **opts):
@@ -87,7 +85,6 @@ class Cmd:
         opts = {}
 
         args = collections.deque([synt for synt in self._cmd_syntax if not synt[0].startswith('-')])
-
         switches = {synt[0]: synt for synt in self._cmd_syntax if synt[0].startswith('-')}
 
         # populate defaults and lists
@@ -125,18 +122,18 @@ class Cmd:
                 snam = swit[0].strip('-')
 
                 if styp == 'valu':
-                    valu, off = s_grammar.parse_cmd_string(text, off)
+                    valu, off = s_parser.parse_cmd_string(text, off)
                     opts[snam] = valu
 
                 elif styp == 'list':
-                    valu, off = s_grammar.parse_cmd_string(text, off)
+                    valu, off = s_parser.parse_cmd_string(text, off)
                     if not isinstance(valu, list):
                         valu = valu.split(',')
                     opts[snam].extend(valu)
 
                 elif styp == 'enum':
                     vals = swit[1].get('enum:vals')
-                    valu, off = s_grammar.parse_cmd_string(text, off)
+                    valu, off = s_parser.parse_cmd_string(text, off)
                     if valu not in vals:
                         raise s_exc.BadSyntax(mesg='%s (%s)' % (swit[0], '|'.join(vals)),
                                                    text=text)
@@ -165,13 +162,13 @@ class Cmd:
                 valu = []
 
                 while off < len(text):
-                    item, off = s_grammar.parse_cmd_string(text, off)
+                    item, off = s_parser.parse_cmd_string(text, off)
                     valu.append(item)
 
                 opts[synt[0]] = valu
                 break
 
-            valu, off = s_grammar.parse_cmd_string(text, off)
+            valu, off = s_parser.parse_cmd_string(text, off)
             opts[synt[0]] = valu
 
         return opts
@@ -234,9 +231,6 @@ class Cli(s_base.Base):
 
         await s_base.Base.__anit__(self)
 
-        # Tell prompt_toolkit to use the asyncio event loop.
-        use_asyncio_event_loop()
-
         if outp is None:
             outp = s_output.OutPut()
 
@@ -310,7 +304,7 @@ class Cli(s_base.Base):
             text = self.cmdprompt
 
         with patch_stdout():
-            retn = await self.sess.prompt(text, async_=True, vi_mode=self.vi_mode, enable_open_in_editor=True)
+            retn = await self.sess.prompt_async(text, vi_mode=self.vi_mode, enable_open_in_editor=True)
             return retn
 
     def printf(self, mesg, addnl=True, color=None):
@@ -322,7 +316,7 @@ class Cli(s_base.Base):
 
         if color is not None:
             mesg = FormattedText([(color, mesg)])
-        return print_formatted_text(mesg)
+        return print_formatted_text(mesg, end='\n' if addnl else '')
 
     def addCmdClass(self, ctor, **opts):
         '''
@@ -359,8 +353,6 @@ class Cli(s_base.Base):
         '''
         while not self.isfini:
 
-            # FIXME completion
-
             self.cmdtask = None
 
             try:
@@ -471,9 +463,9 @@ class CmdHelp(Cmd):
 
     '''
     _cmd_name = 'help'
-    _cmd_syntax = [
-        ('cmds', {'type': 'list'})
-    ]
+    _cmd_syntax = (
+        ('cmds', {'type': 'list'}),  # type: ignore
+    )
 
     async def runCmdOpts(self, opts):
         cmds = opts.get('cmds')
