@@ -3,7 +3,7 @@ Utilities for handling data files embedded within python packages.
 '''
 import os
 
-import synapse.dyndeps as s_dyndeps
+import synapse.lib.dyndeps as s_dyndeps
 
 def openDatFile(datpath):
     '''
