@@ -11,7 +11,7 @@ proprestr = r'[a-z_][a-z0-9]*(:[a-z0-9]+)+([:.][a-z_ ][a-z0-9]+)*'
 proporunivrestr = f'({univrestr})|({proprestr})'
 proporunivre = regex.compile(proporunivrestr)
 propre = regex.compile(proprestr)
-formrestr = r'[a-z][a-z0-9]*(:[a-z0-9]+)+'
+formrestr = r'[a-z_][a-z0-9]*(:[a-z0-9]+)+'
 formre = regex.compile(formrestr)
 tagrestr = r'(\w+\.)*\w+'
 tagre = regex.compile(tagrestr)
