@@ -10,9 +10,78 @@ import aiohttp_socks
 import synapse.exc as s_exc
 import synapse.common as s_common
 
+import synapse.lib.base as s_base
 import synapse.lib.msgpack as s_msgpack
 import synapse.lib.stormtypes as s_stormtypes
 
+@s_stormtypes.registry.registerType
+class WebSocket(s_base.Base, s_stormtypes.StormType):
+    '''
+    Implements the Storm API for a Websocket.
+    '''
+    _storm_typename = 'storm:http:socket'
+
+    _storm_locals = (
+
+        {'name': 'tx', 'desc': 'Transmit a message over the web socket.',
+         'type': {'type': 'function', '_funcname': 'tx',
+                  'args': (
+                      {'name': 'mesg', 'type': 'dict', 'desc': 'A JSON compatible message.', },
+                  ),
+                  'returns': {'type': 'list', 'desc': 'An ($ok, $valu) tuple.'}}},
+
+        {'name': 'rx', 'desc': 'Receive a message from the web socket.',
+         'type': {'type': 'function', '_funcname': 'rx',
+                  'args': (
+                      {'name': 'timeout', 'type': 'int', 'desc': 'The timeout to wait for',
+                       'default': None, },
+                  ),
+                  'returns': {'type': 'list', 'desc': 'An ($ok, $valu) tuple.'}}},
+    )
+
+    async def __anit__(self):
+        await s_base.Base.__anit__(self)
+        s_stormtypes.StormType.__init__(self)
+        self.locls.update(self.getObjLocals())
+
+    def getObjLocals(self):
+        return {
+            'tx': self.tx,
+            'rx': self.rx,
+        }
+
+    async def tx(self, mesg):
+        try:
+
+            mesg = await s_stormtypes.toprim(mesg)
+            await self.resp.send_bytes(json.dumps(mesg).encode())
+            return (True, None)
+
+        except asyncio.CancelledError: # pragma: no cover
+            raise
+
+        except Exception as e: # pragma: no cover
+            return s_common.retnexc(e)
+
+    async def rx(self, timeout=None):
+
+        try:
+            _type, data, extra = await asyncio.wait_for(self.resp.receive(), timeout=timeout)
+            if _type == aiohttp.WSMsgType.BINARY:
+                return (True, json.loads(data))
+            if _type == aiohttp.WSMsgType.TEXT:
+                return (True, json.loads(data.encode()))
+            if _type == aiohttp.WSMsgType.CLOSED: # pragma: no cover
+                return (True, None)
+            return (False, ('BadMesgFormat', {'mesg': f'WebSocket RX unhandled type: {_type.name}'})) # pragma: no cover
+
+        except asyncio.CancelledError: # pragma: no cover
+            raise
+
+        except Exception as e: # pragma: no cover
+            return s_common.retnexc(e)
+
+
 @s_stormtypes.registry.registerLib
 class LibHttp(s_stormtypes.Lib):
     '''
@@ -72,6 +141,18 @@ class LibHttp(s_stormtypes.Lib):
                   'returns': {'type': 'storm:http:resp', 'desc': 'The response object.', }
                   }
          },
+        {'name': 'connect', 'desc': 'Connect a web socket to tx/rx JSON messages.',
+         'type': {'type': 'function', '_funcname': 'inetHttpConnect',
+                  'args': (
+                      {'name': 'url', 'type': 'str', 'desc': 'The URL to retrieve.', },
+                      {'name': 'headers', 'type': 'dict', 'desc': 'HTTP headers to send with the request.',
+                       'default': None, },
+                      {'name': 'ssl_verify', 'type': 'boolean', 'desc': 'Perform SSL/TLS verification.',
+                       'default': True, },
+                      {'name': 'timeout', 'type': 'int', 'desc': 'Total timeout for the request in seconds.',
+                       'default': 300, }
+                  ),
+                  'returns': {'type': 'storm:http:socket', 'desc': 'A websocket object.'}}},
     )
     _storm_lib_path = ('inet', 'http')
 
@@ -80,6 +161,7 @@ class LibHttp(s_stormtypes.Lib):
             'get': self._httpEasyGet,
             'post': self._httpPost,
             'request': self._httpRequest,
+            'connect': self.inetHttpConnect,
         }
 
     async def _httpEasyGet(self, url, headers=None, ssl_verify=True, params=None, timeout=300):
@@ -90,6 +172,33 @@ class LibHttp(s_stormtypes.Lib):
         return await self._httpRequest('POST', url, headers=headers, json=json, body=body,
                                        ssl_verify=ssl_verify, params=params, timeout=timeout)
 
+    async def inetHttpConnect(self, url, headers=None, ssl_verify=True, timeout=300):
+
+        sock = await WebSocket.anit()
+
+        proxyurl = await self.runt.snap.core.getConfOpt('http:proxy')
+        connector = None
+        if proxyurl is not None:
+            connector = aiohttp_socks.ProxyConnector.from_url(proxyurl)
+
+        timeout = aiohttp.ClientTimeout(total=timeout)
+
+        try:
+            sess = await sock.enter_context(aiohttp.ClientSession(connector=connector, timeout=timeout))
+            sock.resp = await sock.enter_context(sess.ws_connect(url, headers=headers, ssl=ssl_verify, timeout=timeout))
+
+            sock._syn_refs = 0
+            self.runt.onfini(sock)
+
+            return (True, sock)
+
+        except asyncio.CancelledError: # pragma: no cover
+            raise
+
+        except Exception as e: # pragma: no cover
+            await sock.fini()
+            return s_common.retnexc(e)
+
     async def _httpRequest(self, meth, url, headers=None, json=None, body=None, ssl_verify=True,
                            params=None, timeout=300):
         meth = await s_stormtypes.tostr(meth)
