@@ -69,3 +69,14 @@ class ModelRevTest(s_tests.SynTest):
         async with self.getRegrCore('model-0.2.2') as core:
             nodes = await core.nodes('inet:web:acct:signup:client:ipv6="::ffff:1.2.3.4"')
             self.len(2001, nodes)
+
+    async def test_modelrev_0_2_3(self):
+
+        async with self.getRegrCore('model-0.2.3') as core:
+
+            nodes = await core.nodes('it:exec:proc:cmd=rar.exe')
+            self.len(2001, nodes)
+
+            nodes = await core.nodes('it:cmd')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef, ('it:cmd', 'rar.exe'))
