@@ -51,7 +51,7 @@ class NodeTest(s_t_utils.SynTest):
                 # a node which has props the second cortex doens't know about.
                 node.props['.newp'] = 1
                 node.props['newp'] = (2, 3)
-                node.tagprops[('foo', 'valu')] = 10
+                node.tagprops['foo']['valu'] = 10
                 iden, info = node.pack(dorepr=True)
                 props, reprs = info.get('props'), info.get('reprs')
                 tagprops, tagpropreprs = info.get('tagprops'), info.get('tagpropreprs')
@@ -262,7 +262,7 @@ class NodeTest(s_t_utils.SynTest):
         async with self.getTestCore() as core:
             async with await core.snap() as snap:
                 query = snap.core.getStormQuery('')
-                with snap.getStormRuntime(query) as runt:
+                async with snap.getStormRuntime(query) as runt:
                     node = await snap.addNode('test:comp', (42, 'lol'))
                     nodepaths = await alist(node.storm(runt, '-> test:int'))
                     self.len(1, nodepaths)
@@ -315,7 +315,7 @@ class NodeTest(s_t_utils.SynTest):
                     # Path clone() creates a fully independent Path object
                     pcln = path.clone()
                     # Ensure that path vars are independent
-                    pcln.setVar('bar', 'us')
+                    await pcln.setVar('bar', 'us')
                     self.eq(pcln.getVar('bar'), 'us')
                     self.eq(path.getVar('bar'), s_common.novalu)
                     # Ensure the path nodes are independent
@@ -333,7 +333,7 @@ class NodeTest(s_t_utils.SynTest):
                     self.eq(pcln.getVar('key'), 'valu')
                     pcln.finiframe()
                     path.finiframe()
-                    pcln.setVar('bar', 'us')
+                    await pcln.setVar('bar', 'us')
                     self.eq(pcln.getVar('bar'), 'us')
                     self.eq(path.getVar('bar'), s_common.novalu)
                     self.eq(pcln.getVar('key'), s_common.novalu)
@@ -414,3 +414,25 @@ class NodeTest(s_t_utils.SynTest):
 
             self.none(await node.getData('foo'))
             self.none(await node.getData('bar'))
+
+    async def test_node_tagprops(self):
+        async with self.getTestCore() as core:
+            await core.addTagProp('score', ('int', {}), {})
+            await core.addTagProp('limit', ('int', {}), {})
+            nodes = await core.nodes('[ test:int=10 ]')
+            node = nodes[0]
+
+            self.eq(node.tagprops, {})
+            await node.setTagProp('foo.test', 'score', 20)
+            await node.setTagProp('foo.test', 'limit', 1000)
+            self.eq(node.tagprops, {'foo.test': {'score': 20, 'limit': 1000}})
+
+            await node.delTagProp('foo.test', 'score')
+            self.eq(node.tagprops, {'foo.test': {'limit': 1000}})
+
+            await node.setTagProp('foo.test', 'score', 50)
+            node.tagprops['foo.test'].pop('score')
+            await node.delTagProp('foo.test', 'score')
+            self.eq(node.tagprops, {'foo.test': {'limit': 1000}})
+            node.tagprops['foo.test'].pop('limit')
+            self.eq(node.tagprops, {'foo.test': {}})
