@@ -519,6 +519,13 @@ class StormSvcTest(s_test.SynTest):
                     self.nn(core.getStormCmd('ohhai'))
                     self.none(core.getStormCmd('goboom'))
 
+                    prim = core.getStormSvc('prim')
+                    refs = prim._syn_refs
+                    await core.nodes('function subr(svc) {} $subr($lib.service.get(prim))')
+                    await core.nodes('function subr(svc) { $other=$svc } $subr($lib.service.get(prim))')
+                    await core.nodes('function subr(svc) { $other=$svc } $t=$subr($lib.service.get(prim))')
+                    self.eq(refs, prim._syn_refs)
+
                     nodes = await core.nodes('[ ps:name=$lib.service.get(prim).lower() ]')
                     self.len(1, nodes)
                     self.eq(nodes[0].ndef[1], 'asdf')
