@@ -43,8 +43,10 @@ class GenPkgTest(s_test.SynTest):
 
             await s_genpkg.main(argv)
 
-            await core.callStorm('testcmd')
-            await core.callStorm('$lib.import(testmod)')
+            msgs = await core.stormlist('testpkgcmd')
+            self.stormIsInPrint('argument <foo> is required', msgs)
+            msgs = await core.stormlist('$mod=$lib.import(testmod) $lib.print($mod)')
+            self.stormIsInPrint('Imported Module testmod', msgs)
 
             pdef = s_common.yamlload(savepath)
 
@@ -56,7 +58,7 @@ class GenPkgTest(s_test.SynTest):
             self.eq(pdef['modules'][1]['storm'], 'inet:fqdn\n')
             self.eq(pdef['modules'][2]['name'], 'testpkg.testextfile')
             self.eq(pdef['modules'][2]['storm'], 'inet:fqdn\n')
-            self.eq(pdef['commands'][0]['name'], 'testcmd')
+            self.eq(pdef['commands'][0]['name'], 'testpkgcmd')
             self.eq(pdef['commands'][0]['storm'], 'inet:ipv6\n')
 
             self.eq(pdef['optic']['files']['index.html']['file'], 'aGkK')
@@ -67,6 +69,18 @@ class GenPkgTest(s_test.SynTest):
             self.eq(pdef['logo']['mime'], 'image/svg')
             self.eq(pdef['logo']['file'], 'c3R1ZmYK')
 
+            # nodocs
+            savepath = s_common.genpath(core.dirn, 'testpkg_nodocs.json')
+            argv = ('--no-docs', '--save', savepath, ymlpath)
+
+            await s_genpkg.main(argv)
+
+            pdef = s_common.yamlload(savepath)
+
+            self.eq(pdef['name'], 'testpkg')
+            self.eq(pdef['docs'][0]['title'], 'Foo Bar')
+            self.eq(pdef['docs'][0]['content'], '')
+
     def test_files(self):
         assets = s_files.getAssets()
         self.isin('test.dat', assets)
