@@ -45,7 +45,7 @@ def loadOpticFiles(pkgdef, path):
                     'file': base64.b64encode(fd.read()).decode(),
                 }
 
-def loadPkgProto(path, opticdir=None):
+def loadPkgProto(path, opticdir=None, no_docs=False):
 
     full = s_common.genpath(path)
     pkgdef = s_common.yamlload(full)
@@ -79,6 +79,10 @@ def loadPkgProto(path, opticdir=None):
             mesg = 'Each entry in docs must have a title.'
             raise s_exc.BadPkgDef(mesg=mesg)
 
+        if no_docs:
+            docdef['content'] = ''
+            continue
+
         path = docdef.pop('path', None)
         if path is not None:
             with s_common.reqfile(protodir, path) as fd:
@@ -135,11 +139,13 @@ async def main(argv, outp=s_output.stdout):
     pars.add_argument('--push', metavar='<url>', help='A telepath URL of a Cortex or PkgRepo.')
     pars.add_argument('--save', metavar='<path>', help='Save the completed package JSON to a file.')
     pars.add_argument('--optic', metavar='<path>', help='Load Optic module files from a directory.')
+    pars.add_argument('--no-docs', default=False, action='store_true',
+                      help='Do not require docs to be present and replace any doc content with empty strings.')
     pars.add_argument('pkgfile', metavar='<pkgfile>', help='Path to a storm package prototype yml file.')
 
     opts = pars.parse_args(argv)
 
-    pkgdef = loadPkgProto(opts.pkgfile, opticdir=opts.optic)
+    pkgdef = loadPkgProto(opts.pkgfile, opticdir=opts.optic, no_docs=opts.no_docs)
 
     if opts.save:
         s_common.jssave(pkgdef, opts.save)
